@@ -19,33 +19,32 @@
 #ifndef __XFMPC_MPDCLIENT_H__
 #define __XFMPC_MPDCLIENT_H__
 
-#include <glib.h>
-#include <libmpd/libmpd.h>
+G_BEGIN_DECLS
 
-typedef struct _XfmpcMpdclient          XfmpcMpdclient;
+#define XFMPC_TYPE_MPDCLIENT                (xfmpc_mpdclient_get_type())
 
-struct _XfmpcMpdclient
-{
-  MpdObj               *mi;
-  gchar                *host;
-  guint                 port;
-  gchar                *passwd;
+#define XFMPC_MPDCLIENT(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFMPC_TYPE_MPDCLIENT, XfmpcMpdclient))
+#define XFMPC_MPDCLIENT_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), XFMPC_TYPE_MPDCLIENT, XfmpcMpdclientClass))
 
-  guint8                volume;
-};
+#define XFMPC_IS_MPDCLIENT(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XFMPC_TYPE_MPDCLIENT))
+#define XFMPC_IS_MPDCLIENT_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), XFMPC_TYPE_MPDCLIENT))
+
+#define XFMPC_MPDCLIENT_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), XFMPC_TYPE_MPDCLIENT, XfmpcMpdclientClass))
+
+typedef struct _XfmpcMpdclientClass         XfmpcMpdclientClass;
+typedef struct _XfmpcMpdclient              XfmpcMpdclient;
+typedef struct _XfmpcMpdclientPrivate       XfmpcMpdclientPrivate;
+
+GType                   xfmpc_mpdclient_get_type                () G_GNUC_CONST;
 
 XfmpcMpdclient *        xfmpc_mpdclient_new                     ();
 
-void                    xfmpc_mpdclient_initenv                 (XfmpcMpdclient *mpdclient);
-
 gboolean                xfmpc_mpdclient_connect                 (XfmpcMpdclient *mpdclient);
 
 void                    xfmpc_mpdclient_disconnect              (XfmpcMpdclient *mpdclient);
 
 gboolean                xfmpc_mpdclient_is_connected            (XfmpcMpdclient *mpdclient);
 
-void                    xfmpc_mpdclient_free                    (XfmpcMpdclient *mpdclient);
-
 gboolean                xfmpc_mpdclient_previous                (XfmpcMpdclient *mpdclient);
 
 gboolean                xfmpc_mpdclient_pp                      (XfmpcMpdclient *mpdclient);
@@ -58,13 +57,13 @@ gboolean                xfmpc_mpdclient_stop                    (XfmpcMpdclient
 
 gboolean                xfmpc_mpdclient_next                    (XfmpcMpdclient *mpdclient);
 
+gboolean                xfmpc_mpdclient_set_id                  (XfmpcMpdclient *mpdclient,
+                                                                 gint id);
 gboolean                xfmpc_mpdclient_set_volume              (XfmpcMpdclient *mpdclient,
                                                                  guint8 volume);
 gboolean                xfmpc_mpdclient_set_song_time           (XfmpcMpdclient *mpdclient,
                                                                  guint time);
-gboolean                xfmpc_mpdclient_is_playing              (XfmpcMpdclient *mpdclient);
-
-gboolean                xfmpc_mpdclient_is_stopped              (XfmpcMpdclient *mpdclient);
+gint                    xfmpc_mpdclient_get_id                  (XfmpcMpdclient *mpdclient);
 
 const gchar *           xfmpc_mpdclient_get_artist              (XfmpcMpdclient *mpdclient);
 
@@ -80,5 +79,22 @@ gint                    xfmpc_mpdclient_get_total_time          (XfmpcMpdclient
 
 guint8                  xfmpc_mpdclient_get_volume              (XfmpcMpdclient *mpdclient);
 
+gboolean                xfmpc_mpdclient_is_playing              (XfmpcMpdclient *mpdclient);
+
+gboolean                xfmpc_mpdclient_is_stopped              (XfmpcMpdclient *mpdclient);
+
+void                    xfmpc_mpdclient_update_status           (XfmpcMpdclient *mpdclient);
+
+gboolean                xfmpc_mpdclient_playlist_read           (XfmpcMpdclient *mpdclient,
+                                                                 gint *id,
+                                                                 gchar **song,
+                                                                 gchar **length);
+gboolean                xfmpc_mpdclient_queue_commit            (XfmpcMpdclient *mpdclient);
+
+gboolean                xfmpc_mpdclient_queue_remove_id         (XfmpcMpdclient *mpdclient,
+                                                                 gint id);
+
+G_END_DECLS
+
 #endif
 
